(v0.11.4)=
### 0.11.4 {small}`2025-03-26`

#### Bug fixes

- Raise {class}`~anndata.ImplicitModificationWarning` when setting `X` on a view. {user}`ilan-gold` ({pr}`1853`)
- Bound `dask` due to {issue}`dask/dask#11752` {user}`ilan-gold` ({pr}`1859`)
- Fix concatenation of {class}`anndata.AnnData` objects along `var` using `join="outer"` when `varm` is not empty. {user}`ilia-kats` ({pr}`1911`)
- Add `convert_strings_to_categoricals` parameter also to {meth}`~anndata.AnnData.write_h5ad` and {meth}`~anndata.AnnData.write_zarr` as intended {user}`flying-sheep` ({pr}`1914`)
- Allow initialization of {class}`anndata.AnnData` objects without `X` (since they could be constructed previously by deleting `X`) {user}`ilan-gold` ({pr}`1941`)

#### Development Process

- Fix version number inference in development environments (CI and local) {user}`flying-sheep` ({pr}`1831`)
